import { Stack } from '../Stack/Stack.js';
import classes from './FilteredActionListLoaders.module.css.js';
import { jsx, Fragment, jsxs } from 'react/jsx-runtime';
import Box from '../Box/Box.js';
import { SkeletonBox } from '../Skeleton/SkeletonBox.js';
import StyledSpinner from '../Spinner/Spinner.js';

class FilteredActionListLoadingType {
  constructor(name, appearsInBody) {
    this.name = name;
    this.appearsInBody = appearsInBody;
  }
}
const FilteredActionListLoadingTypes = {
  bodySpinner: new FilteredActionListLoadingType('body-spinner', true),
  bodySkeleton: new FilteredActionListLoadingType('body-skeleton', true),
  input: new FilteredActionListLoadingType('input', false)
};
const SKELETON_ROW_HEIGHT = 24;
const SKELETON_MIN_ROWS = 3;
function FilteredActionListBodyLoader({
  loadingType,
  height
}) {
  switch (loadingType) {
    case FilteredActionListLoadingTypes.bodySpinner:
      return /*#__PURE__*/jsx(LoadingSpinner, {
        "data-testid": "filtered-action-list-spinner"
      });
    case FilteredActionListLoadingTypes.bodySkeleton:
      {
        const rows = height < SKELETON_ROW_HEIGHT ? SKELETON_MIN_ROWS : height / SKELETON_ROW_HEIGHT;
        return /*#__PURE__*/jsx(LoadingSkeleton, {
          "data-testid": "filtered-action-list-skeleton",
          rows: rows
        });
      }
    default:
      return /*#__PURE__*/jsx(Fragment, {});
  }
}
function LoadingSpinner({
  ...props
}) {
  return /*#__PURE__*/jsx(Box, {
    p: 3,
    flexGrow: 1,
    sx: {
      alignContent: 'center',
      textAlign: 'center',
      height: '100%'
    },
    children: /*#__PURE__*/jsx(StyledSpinner, {
      ...props
    })
  });
}
LoadingSpinner.displayName = "LoadingSpinner";
function LoadingSkeleton({
  rows = 10,
  ...props
}) {
  return /*#__PURE__*/jsx(Box, {
    p: 2,
    display: "flex",
    flexGrow: 1,
    flexDirection: "column",
    children: /*#__PURE__*/jsx(Stack, {
      direction: "vertical",
      justify: "center",
      gap: "condensed",
      ...props,
      children: Array.from({
        length: rows
      }, (_, i) => /*#__PURE__*/jsxs(Stack, {
        direction: "horizontal",
        gap: "condensed",
        align: "center",
        children: [/*#__PURE__*/jsx(SkeletonBox, {
          width: "16px",
          height: "16px"
        }), /*#__PURE__*/jsx(SkeletonBox, {
          height: "10px",
          width: `${Math.random() * 60 + 20}%`,
          className: classes.LoadingSkeleton
        })]
      }, i))
    })
  });
}
LoadingSkeleton.displayName = "LoadingSkeleton";

export { FilteredActionListBodyLoader, FilteredActionListLoadingType, FilteredActionListLoadingTypes };
