'use strict';

var React = require('react');
var octiconsReact = require('@primer/octicons-react');
var index = require('../ActionList/index.js');
var useIsomorphicLayoutEffect = require('../utils/useIsomorphicLayoutEffect.js');
var useOnEscapePress = require('../hooks/useOnEscapePress.js');
var useResizeObserver = require('../hooks/useResizeObserver.js');
var useOnOutsideClick = require('../hooks/useOnOutsideClick.js');
var IconButton = require('../Button/IconButton.js');
var useFocusZone = require('../hooks/useFocusZone.js');
var ActionBar_module = require('./ActionBar.module.css.js');
var clsx = require('clsx');
var jsxRuntime = require('react/jsx-runtime');
var behaviors = require('@primer/behaviors');
var ActionMenu = require('../ActionMenu/ActionMenu.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

const ActionBarContext = /*#__PURE__*/React__default.default.createContext({
  size: 'medium',
  setChildrenWidth: () => null
});

/*
small (28px), medium (32px), large (40px)
*/

const MORE_BTN_WIDTH = 86;
const getValidChildren = children => {
  return React__default.default.Children.toArray(children).filter(child => {
    return /*#__PURE__*/React__default.default.isValidElement(child);
  });
};
const calculatePossibleItems = (childWidthArray, navWidth, moreMenuWidth = 0) => {
  const widthToFit = navWidth - moreMenuWidth;
  let breakpoint = childWidthArray.length; // assume all items will fit
  let sumsOfChildWidth = 0;
  for (const [index, childWidth] of childWidthArray.entries()) {
    sumsOfChildWidth = sumsOfChildWidth + childWidth.width; // + GAP
    if (sumsOfChildWidth > widthToFit) {
      breakpoint = index;
      break;
    } else {
      continue;
    }
  }
  return breakpoint;
};
const overflowEffect = (navWidth, moreMenuWidth, childArray, childWidthArray, updateListAndMenu, hasActiveMenu) => {
  if (childWidthArray.length === 0) {
    updateListAndMenu({
      items: childArray,
      menuItems: []
    });
  }
  const numberOfItemsPossible = calculatePossibleItems(childWidthArray, navWidth);
  const numberOfItemsPossibleWithMoreMenu = calculatePossibleItems(childWidthArray, navWidth, moreMenuWidth || MORE_BTN_WIDTH);
  const items = [];
  const menuItems = [];

  // First, we check if we can fit all the items with their icons
  if (childArray.length >= numberOfItemsPossible) {
    /* Below is an accessibility requirement. Never show only one item in the overflow menu.
     * If there is only one item left to display in the overflow menu according to the calculation,
     * we need to pull another item from the list into the overflow menu.
     */
    const numberOfItemsInMenu = childArray.length - numberOfItemsPossibleWithMoreMenu;
    const numberOfListItems = numberOfItemsInMenu === 1 ? numberOfItemsPossibleWithMoreMenu - 1 : numberOfItemsPossibleWithMoreMenu;
    for (const [index$1, child] of childArray.entries()) {
      if (index$1 < numberOfListItems) {
        items.push(child);
        //if the last item is a divider
      } else if (childWidthArray[index$1].text === 'divider') {
        if (index$1 === numberOfListItems - 1 || index$1 === numberOfListItems) {
          continue;
        } else {
          const divider = /*#__PURE__*/React__default.default.createElement(index.ActionList.Divider, {
            key: index$1
          });
          menuItems.push(divider);
        }
      } else {
        menuItems.push(child);
      }
    }
    updateListAndMenu({
      items,
      menuItems
    });
  } else if (numberOfItemsPossible > childArray.length && hasActiveMenu) {
    /* If the items fit in the list and there are items in the overflow menu, we need to move them back to the list */
    updateListAndMenu({
      items: childArray,
      menuItems: []
    });
  }
};
const ActionBar = props => {
  const {
    size = 'medium',
    children,
    'aria-label': ariaLabel,
    flush = false,
    className
  } = props;
  const [childWidthArray, setChildWidthArray] = React.useState([]);
  const setChildrenWidth = React.useCallback(size => {
    setChildWidthArray(arr => {
      const newArr = [...arr, size];
      return newArr;
    });
  }, []);
  const navRef = React.useRef(null);
  const listRef = React.useRef(null);
  const moreMenuRef = React.useRef(null);
  const moreMenuBtnRef = React.useRef(null);
  const containerRef = React__default.default.useRef(null);
  const validChildren = getValidChildren(children);
  // Responsive props object manages which items are in the list and which items are in the menu.
  const [responsiveProps, setResponsiveProps] = React.useState({
    items: validChildren,
    menuItems: []
  });

  // Make sure to have the fresh props data for list items when children are changed (keeping aria-current up-to-date)
  const listItems = responsiveProps.items.map(item => {
    var _validChildren$find;
    return (_validChildren$find = validChildren.find(child => child.key === item.key)) !== null && _validChildren$find !== void 0 ? _validChildren$find : item;
  });

  // Make sure to have the fresh props data for menu items when children are changed (keeping aria-current up-to-date)
  const menuItems = responsiveProps.menuItems.map(menuItem => {
    var _validChildren$find2;
    return (_validChildren$find2 = validChildren.find(child => child.key === menuItem.key)) !== null && _validChildren$find2 !== void 0 ? _validChildren$find2 : menuItem;
  });
  const updateListAndMenu = React.useCallback(props => {
    setResponsiveProps(props);
  }, []);
  useResizeObserver.useResizeObserver(resizeObserverEntries => {
    var _moreMenuRef$current$, _moreMenuRef$current;
    const navWidth = resizeObserverEntries[0].contentRect.width;
    const moreMenuWidth = (_moreMenuRef$current$ = (_moreMenuRef$current = moreMenuRef.current) === null || _moreMenuRef$current === void 0 ? void 0 : _moreMenuRef$current.getBoundingClientRect().width) !== null && _moreMenuRef$current$ !== void 0 ? _moreMenuRef$current$ : 0;
    const hasActiveMenu = menuItems.length > 0;
    navWidth !== 0 && overflowEffect(navWidth, moreMenuWidth, validChildren, childWidthArray, updateListAndMenu, hasActiveMenu);
  }, navRef);
  const [isWidgetOpen, setIsWidgetOpen] = React.useState(false);
  const closeOverlay = React__default.default.useCallback(() => {
    setIsWidgetOpen(false);
  }, [setIsWidgetOpen]);
  const focusOnMoreMenuBtn = React__default.default.useCallback(() => {
    var _moreMenuBtnRef$curre;
    (_moreMenuBtnRef$curre = moreMenuBtnRef.current) === null || _moreMenuBtnRef$curre === void 0 ? void 0 : _moreMenuBtnRef$curre.focus();
  }, []);
  useOnEscapePress.useOnEscapePress(event => {
    if (isWidgetOpen) {
      event.preventDefault();
      closeOverlay();
      focusOnMoreMenuBtn();
    }
  }, [isWidgetOpen]);
  useOnOutsideClick.useOnOutsideClick({
    onClickOutside: closeOverlay,
    containerRef,
    ignoreClickRefs: [moreMenuBtnRef]
  });
  useFocusZone.useFocusZone({
    containerRef: listRef,
    bindKeys: behaviors.FocusKeys.ArrowHorizontal | behaviors.FocusKeys.HomeAndEnd,
    focusOutBehavior: 'wrap'
  });
  return /*#__PURE__*/jsxRuntime.jsx(ActionBarContext.Provider, {
    value: {
      size,
      setChildrenWidth
    },
    children: /*#__PURE__*/jsxRuntime.jsx("div", {
      ref: navRef,
      className: clsx.clsx(className, ActionBar_module.Nav),
      "data-flush": flush,
      children: /*#__PURE__*/jsxRuntime.jsxs("div", {
        ref: listRef,
        role: "toolbar",
        className: ActionBar_module.List,
        children: [listItems, menuItems.length > 0 && /*#__PURE__*/jsxRuntime.jsxs(ActionMenu.ActionMenu, {
          children: [/*#__PURE__*/jsxRuntime.jsx(ActionMenu.ActionMenu.Anchor, {
            children: /*#__PURE__*/jsxRuntime.jsx(IconButton.IconButton, {
              variant: "invisible",
              "aria-label": `More ${ariaLabel} items`,
              icon: octiconsReact.KebabHorizontalIcon
            })
          }), /*#__PURE__*/jsxRuntime.jsx(ActionMenu.ActionMenu.Overlay, {
            children: /*#__PURE__*/jsxRuntime.jsx(index.ActionList, {
              children: menuItems.map((menuItem, index$1) => {
                if (menuItem.type === index.ActionList.Divider) {
                  return /*#__PURE__*/jsxRuntime.jsx(index.ActionList.Divider, {}, index$1);
                } else {
                  const {
                    children: menuItemChildren,
                    onClick,
                    icon: Icon,
                    'aria-label': ariaLabel,
                    disabled
                  } = menuItem.props;
                  return /*#__PURE__*/jsxRuntime.jsxs(index.ActionList.Item, {
                    // eslint-disable-next-line primer-react/prefer-action-list-item-onselect
                    onClick: event => {
                      closeOverlay();
                      focusOnMoreMenuBtn();
                      typeof onClick === 'function' && onClick(event);
                    },
                    disabled: disabled,
                    children: [Icon ? /*#__PURE__*/jsxRuntime.jsx(index.ActionList.LeadingVisual, {
                      children: /*#__PURE__*/jsxRuntime.jsx(Icon, {})
                    }) : null, ariaLabel]
                  }, menuItemChildren);
                }
              })
            })
          })]
        })]
      })
    })
  });
};
ActionBar.displayName = "ActionBar";
const ActionBarIconButton = /*#__PURE__*/React.forwardRef(({
  disabled,
  onClick,
  ...props
}, forwardedRef) => {
  const backupRef = React.useRef(null);
  const ref = forwardedRef !== null && forwardedRef !== void 0 ? forwardedRef : backupRef;
  const {
    size,
    setChildrenWidth
  } = React__default.default.useContext(ActionBarContext);
  useIsomorphicLayoutEffect(() => {
    const text = props['aria-label'] ? props['aria-label'] : '';
    const domRect = ref.current.getBoundingClientRect();
    setChildrenWidth({
      text,
      width: domRect.width
    });
  }, [ref, setChildrenWidth]);
  const clickHandler = React.useCallback(event => {
    if (disabled) return;
    onClick === null || onClick === void 0 ? void 0 : onClick(event);
  }, [disabled, onClick]);
  return /*#__PURE__*/jsxRuntime.jsx(IconButton.IconButton, {
    "aria-disabled": disabled,
    ref: ref,
    size: size,
    onClick: clickHandler,
    ...props,
    variant: "invisible"
  });
});
const VerticalDivider = () => {
  const ref = React.useRef(null);
  const {
    setChildrenWidth
  } = React__default.default.useContext(ActionBarContext);
  useIsomorphicLayoutEffect(() => {
    const text = 'divider';
    const domRect = ref.current.getBoundingClientRect();
    setChildrenWidth({
      text,
      width: domRect.width
    });
  }, [ref, setChildrenWidth]);
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    ref: ref,
    "data-component": "ActionBar.VerticalDivider",
    "aria-hidden": "true",
    className: ActionBar_module.Divider
  });
};
VerticalDivider.displayName = "VerticalDivider";

exports.ActionBar = ActionBar;
exports.ActionBarIconButton = ActionBarIconButton;
exports.VerticalDivider = VerticalDivider;
