'use strict';

var React = require('react');
var octiconsReact = require('@primer/octicons-react');
var Group = require('./Group.js');
var shared = require('./shared.js');
var Visuals = require('./Visuals.js');
var ActionList_module = require('./ActionList.module.css.js');
var jsxRuntime = require('react/jsx-runtime');
var Radio = require('../Radio/Radio.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

const Selection = ({
  selected,
  className
}) => {
  const {
    selectionVariant: listSelectionVariant,
    role: listRole
  } = React__default.default.useContext(shared.ListContext);
  const {
    selectionVariant: groupSelectionVariant
  } = React__default.default.useContext(Group.GroupContext);

  /** selectionVariant in Group can override the selectionVariant in List root */
  /** fallback to selectionVariant from container menu if any (ActionMenu, SelectPanel ) */
  let selectionVariant;
  if (typeof groupSelectionVariant !== 'undefined') selectionVariant = groupSelectionVariant;else selectionVariant = listSelectionVariant;
  if (!selectionVariant) {
    // if selectionVariant is not set on List, but Item is selected
    // fail loudly instead of silently ignoring
    if (selected) {
      throw new Error('For Item to be selected, ActionList or ActionList.Group needs to have a selectionVariant defined');
    } else {
      return null;
    }
  }
  if (selectionVariant === 'radio') {
    return /*#__PURE__*/jsxRuntime.jsx(Visuals.VisualContainer, {
      className: className,
      "data-component": "ActionList.Selection",
      children: /*#__PURE__*/jsxRuntime.jsx(Radio, {
        value: "unused",
        checked: selected,
        "aria-hidden": true,
        tabIndex: -1
      })
    });
  }
  if (selectionVariant === 'single' || listRole === 'menu') {
    return /*#__PURE__*/jsxRuntime.jsx(Visuals.VisualContainer, {
      className: className,
      "data-component": "ActionList.Selection",
      children: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.CheckIcon, {
        className: ActionList_module.SingleSelectCheckmark
      })
    });
  }
  return /*#__PURE__*/jsxRuntime.jsx(Visuals.VisualContainer, {
    className: className,
    "data-component": "ActionList.Selection",
    children: /*#__PURE__*/jsxRuntime.jsx("div", {
      className: ActionList_module.MultiSelectCheckbox
    })
  });
};
Selection.displayName = "Selection";

exports.Selection = Selection;
