'use strict';

var React = require('react');
var octiconsReact = require('@primer/octicons-react');
var shared = require('./shared.js');
var clsx = require('clsx');
var ActionList_module = require('./ActionList.module.css.js');
var defaultSxProp = require('../utils/defaultSxProp.js');
var BoxWithFallback = require('../internal/components/BoxWithFallback.js');
var jsxRuntime = require('react/jsx-runtime');
var Tooltip = require('../TooltipV2/Tooltip.js');
var Spinner = require('../Spinner/Spinner.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

const VisualContainer = ({
  sx = defaultSxProp.defaultSxProp,
  className,
  ...props
}) => {
  return /*#__PURE__*/jsxRuntime.jsx(BoxWithFallback.BoxWithFallback, {
    as: "span",
    className: clsx.clsx(className, ActionList_module.VisualWrap),
    sx: sx,
    ...props
  });
};
VisualContainer.displayName = "VisualContainer";
const LeadingVisual = ({
  sx = defaultSxProp.defaultSxProp,
  className,
  ...props
}) => {
  return /*#__PURE__*/jsxRuntime.jsx(VisualContainer, {
    className: clsx.clsx(className, ActionList_module.LeadingVisual),
    sx: sx,
    ...props,
    children: props.children
  });
};
LeadingVisual.displayName = "LeadingVisual";
const TrailingVisual = ({
  sx = defaultSxProp.defaultSxProp,
  className,
  ...props
}) => {
  const {
    trailingVisualId
  } = React__default.default.useContext(shared.ItemContext);
  return /*#__PURE__*/jsxRuntime.jsx(VisualContainer, {
    className: clsx.clsx(className, ActionList_module.TrailingVisual),
    sx: sx,
    id: trailingVisualId,
    ...props,
    children: props.children
  });
};
TrailingVisual.displayName = "TrailingVisual";
// VisualOrIndicator handles the positioning of indicators and determines whether to show a visual or an indicator.
//
// If we're showing an *inactive* or *loading* indicator and a leading visual has NOT been passed,
// replace the trailing visual with the inactive indicator.
//
// This preserves the left alignment of item text.
const VisualOrIndicator = ({
  children,
  labelId,
  loading,
  inactiveText,
  itemHasLeadingVisual,
  position,
  className
}) => {
  const VisualComponent = position === 'leading' ? LeadingVisual : TrailingVisual;
  if (!loading && !inactiveText) return children;
  if (itemHasLeadingVisual && position === 'trailing' ||
  // has a leading visual, and it's in the trailing position, or
  !itemHasLeadingVisual && position === 'leading' // it doesn't have a leading visual, and it's in the leading position
  ) {
    // => so we don't render the indicator here
    return children;
  }
  return inactiveText ? /*#__PURE__*/jsxRuntime.jsx("span", {
    className: ActionList_module.InactiveButtonWrap,
    children: /*#__PURE__*/jsxRuntime.jsx(Tooltip.Tooltip, {
      text: inactiveText,
      type: "description",
      children: /*#__PURE__*/jsxRuntime.jsx("button", {
        type: "button",
        className: ActionList_module.InactiveButtonReset,
        "aria-labelledby": labelId,
        children: /*#__PURE__*/jsxRuntime.jsx(VisualComponent, {
          children: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.AlertIcon, {})
        })
      })
    })
  }) : /*#__PURE__*/jsxRuntime.jsx(VisualComponent, {
    className: className,
    children: /*#__PURE__*/jsxRuntime.jsx(Spinner, {
      size: "small"
    })
  });
};
LeadingVisual.displayName = 'ActionList.LeadingVisual';
TrailingVisual.displayName = 'ActionList.TrailingVisual';

exports.LeadingVisual = LeadingVisual;
exports.TrailingVisual = TrailingVisual;
exports.VisualContainer = VisualContainer;
exports.VisualOrIndicator = VisualOrIndicator;
