'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var clsx = require('clsx');
var React = require('react');
var useResponsiveValue = require('../hooks/useResponsiveValue.js');
var defaultSxProp = require('../utils/defaultSxProp.js');
var BoxWithFallback = require('../internal/components/BoxWithFallback.js');
var Avatar_module = require('./Avatar.module.css.js');
var jsxRuntime = require('react/jsx-runtime');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

const DEFAULT_AVATAR_SIZE = 20;
const Avatar = /*#__PURE__*/React__default.default.forwardRef(function Avatar({
  alt = '',
  size = DEFAULT_AVATAR_SIZE,
  square = false,
  sx: sxProp = defaultSxProp.defaultSxProp,
  className,
  style,
  ...rest
}, ref) {
  const isResponsive = useResponsiveValue.isResponsiveValue(size);
  const cssSizeVars = {};
  if (isResponsive) {
    for (const [key, value] of Object.entries(size)) {
      cssSizeVars[`--avatarSize-${key}`] = `${value}px`;
    }
  } else {
    cssSizeVars['--avatarSize-regular'] = `${size}px`;
  }
  return /*#__PURE__*/jsxRuntime.jsx(BoxWithFallback.BoxWithFallback, {
    as: "img",
    "data-component": "Avatar",
    className: clsx.clsx(className, Avatar_module.Avatar),
    ref: ref,
    alt: alt,
    "data-responsive": isResponsive ? '' : undefined,
    "data-square": square ? '' : undefined,
    width: isResponsive ? undefined : size,
    height: isResponsive ? undefined : size,
    style: style ? {
      ...cssSizeVars,
      ...style
    } : cssSizeVars,
    sx: sxProp,
    ...rest
  });
});
if (process.env.NODE_ENV !== "production") {
  Avatar.displayName = 'Avatar';
}

exports.DEFAULT_AVATAR_SIZE = DEFAULT_AVATAR_SIZE;
exports.default = Avatar;
