'use strict';

var clsx = require('clsx');
var React = require('react');
var octiconsReact = require('@primer/octicons-react');
var IconButton = require('../Button/IconButton.js');
var Button = require('../Button/Button.js');
var useMergedRefs = require('../internal/hooks/useMergedRefs.js');
var Banner_module = require('./Banner.module.css.js');
var jsxRuntime = require('react/jsx-runtime');
var VisuallyHidden = require('../VisuallyHidden/VisuallyHidden.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

const iconForVariant = {
  critical: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.StopIcon, {}),
  info: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.InfoIcon, {}),
  success: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.CheckCircleIcon, {}),
  upsell: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.InfoIcon, {}),
  warning: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.AlertIcon, {})
};
const labels = {
  critical: 'Critical',
  info: 'Information',
  success: 'Success',
  upsell: 'Recommendation',
  warning: 'Warning'
};
const Banner = /*#__PURE__*/React__default.default.forwardRef(function Banner({
  'aria-label': label,
  children,
  className,
  description,
  hideTitle,
  icon,
  onDismiss,
  primaryAction,
  secondaryAction,
  title,
  variant = 'info',
  ...rest
}, forwardRef) {
  const dismissible = !!onDismiss;
  const hasActions = primaryAction || secondaryAction;
  const bannerRef = React__default.default.useRef(null);
  const ref = useMergedRefs.useMergedRefs(forwardRef, bannerRef);
  const supportsCustomIcon = variant === 'info' || variant === 'upsell';
  if (process.env.NODE_ENV !== "production") {
    // This hook is called consistently depending on the environment
    // eslint-disable-next-line react-compiler/react-compiler
    // eslint-disable-next-line react-hooks/rules-of-hooks
    React.useEffect(() => {
      if (title) {
        return;
      }
      const {
        current: banner
      } = bannerRef;
      if (!banner) {
        return;
      }
      const hasTitle = banner.querySelector('[data-banner-title]');
      if (!hasTitle) {
        throw new Error('Expected a title to be provided to the <Banner> component with the `title` prop or through `<Banner.Title>` but no title was found');
      }
    }, [title]);
  }
  return /*#__PURE__*/jsxRuntime.jsxs("section", {
    ...rest,
    "aria-label": label !== null && label !== void 0 ? label : labels[variant],
    className: clsx.clsx(className, Banner_module.Banner),
    "data-dismissible": onDismiss ? '' : undefined,
    "data-title-hidden": hideTitle ? '' : undefined,
    "data-variant": variant,
    tabIndex: -1,
    ref: ref,
    children: [/*#__PURE__*/jsxRuntime.jsx("div", {
      className: Banner_module.BannerIcon,
      children: icon && supportsCustomIcon ? icon : iconForVariant[variant]
    }), /*#__PURE__*/jsxRuntime.jsxs("div", {
      className: Banner_module.BannerContainer,
      children: [/*#__PURE__*/jsxRuntime.jsxs("div", {
        className: Banner_module.BannerContent,
        children: [title ? hideTitle ? /*#__PURE__*/jsxRuntime.jsx(VisuallyHidden.VisuallyHidden, {
          children: /*#__PURE__*/jsxRuntime.jsx(BannerTitle, {
            children: title
          })
        }) : /*#__PURE__*/jsxRuntime.jsx(BannerTitle, {
          children: title
        }) : null, description ? /*#__PURE__*/jsxRuntime.jsx(BannerDescription, {
          children: description
        }) : null, children]
      }), hasActions ? /*#__PURE__*/jsxRuntime.jsx(BannerActions, {
        primaryAction: primaryAction,
        secondaryAction: secondaryAction
      }) : null]
    }), dismissible ? /*#__PURE__*/jsxRuntime.jsx(IconButton.IconButton, {
      "aria-label": "Dismiss banner",
      onClick: onDismiss,
      className: Banner_module.BannerDismiss,
      icon: octiconsReact.XIcon,
      variant: "invisible"
    }) : null]
  });
});
function BannerTitle(props) {
  const {
    as: Heading = 'h2',
    className,
    children,
    ...rest
  } = props;
  return /*#__PURE__*/jsxRuntime.jsx(Heading, {
    ...rest,
    className: clsx.clsx(className, Banner_module.BannerTitle),
    "data-banner-title": "",
    children: children
  });
}
BannerTitle.displayName = "BannerTitle";
function BannerDescription({
  children,
  className,
  ...rest
}) {
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    ...rest,
    className: clsx.clsx('BannerDescription', className),
    children: children
  });
}
BannerDescription.displayName = "BannerDescription";
function BannerActions({
  primaryAction,
  secondaryAction
}) {
  return /*#__PURE__*/jsxRuntime.jsxs("div", {
    className: Banner_module.BannerActions,
    children: [/*#__PURE__*/jsxRuntime.jsxs("div", {
      className: Banner_module.BannerActionsContainer,
      "data-primary-action": "trailing",
      children: [secondaryAction !== null && secondaryAction !== void 0 ? secondaryAction : null, primaryAction !== null && primaryAction !== void 0 ? primaryAction : null]
    }), /*#__PURE__*/jsxRuntime.jsxs("div", {
      className: Banner_module.BannerActionsContainer,
      "data-primary-action": "leading",
      children: [primaryAction !== null && primaryAction !== void 0 ? primaryAction : null, secondaryAction !== null && secondaryAction !== void 0 ? secondaryAction : null]
    })]
  });
}
BannerActions.displayName = "BannerActions";
const BannerPrimaryAction = /*#__PURE__*/React.forwardRef(({
  children,
  className,
  ...rest
}, forwardedRef) => {
  return /*#__PURE__*/jsxRuntime.jsx(Button.ButtonComponent, {
    ref: forwardedRef,
    className: clsx.clsx('BannerPrimaryAction', className),
    variant: "default",
    ...rest,
    children: children
  });
});
BannerPrimaryAction.displayName = 'BannerPrimaryAction';
const BannerSecondaryAction = /*#__PURE__*/React.forwardRef(({
  children,
  className,
  ...rest
}, forwardedRef) => {
  return /*#__PURE__*/jsxRuntime.jsx(Button.ButtonComponent, {
    ref: forwardedRef,
    className: clsx.clsx('BannerPrimaryAction', className),
    variant: "link",
    ...rest,
    children: children
  });
});
BannerSecondaryAction.displayName = 'BannerSecondaryAction';

exports.Banner = Banner;
exports.BannerActions = BannerActions;
exports.BannerDescription = BannerDescription;
exports.BannerPrimaryAction = BannerPrimaryAction;
exports.BannerSecondaryAction = BannerSecondaryAction;
exports.BannerTitle = BannerTitle;
