'use strict';

var clsx = require('clsx');
var ThemeProvider = require('./ThemeProvider.js');
var BaseStyles_module = require('./BaseStyles.module.css.js');
require('focus-visible');
var BoxWithFallback = require('./internal/components/BoxWithFallback.js');
var jsxRuntime = require('react/jsx-runtime');

function BaseStyles({
  children,
  color,
  fontFamily,
  lineHeight,
  className,
  as: Component = 'div',
  style,
  ...rest
}) {
  const {
    colorMode,
    colorScheme,
    dayScheme,
    nightScheme
  } = ThemeProvider.useTheme();
  const newClassName = clsx.clsx(BaseStyles_module.BaseStyles, className);
  const baseStyles = {
    ['--BaseStyles-fgColor']: color,
    ['--BaseStyles-fontFamily']: fontFamily,
    ['--BaseStyles-lineHeight']: lineHeight
  };
  return /*#__PURE__*/jsxRuntime.jsx(BoxWithFallback.BoxWithFallback, {
    as: Component,
    className: newClassName,
    "data-portal-root": true
    /**
     * We need to map valid primer/react color modes onto valid color modes for primer/primitives
     * valid color modes for primer/primitives: auto | light | dark
     * valid color modes for primer/primer: auto | day | night | light | dark
     */,
    "data-color-mode": colorMode === 'auto' ? 'auto' : colorScheme !== null && colorScheme !== void 0 && colorScheme.includes('dark') ? 'dark' : 'light',
    "data-light-theme": dayScheme,
    "data-dark-theme": nightScheme,
    style: {
      ...baseStyles,
      ...style
    },
    ...rest,
    children: children
  });
}
BaseStyles.displayName = "BaseStyles";

module.exports = BaseStyles;
