'use strict';

var clsx = require('clsx');
var React = require('react');
var BlankslateContext = require('./BlankslateContext.js');
var Blankslate_module = require('./Blankslate.module.css.js');
var jsxRuntime = require('react/jsx-runtime');
var Link = require('../Link/Link.js');
var Button = require('../Button/Button.js');

function Blankslate({
  border,
  children,
  narrow,
  spacious,
  className,
  size = 'medium',
  ...rest
}) {
  const value = React.useMemo(() => {
    return {
      size
    };
  }, [size]);
  return /*#__PURE__*/jsxRuntime.jsx(BlankslateContext.Provider, {
    value: value,
    children: /*#__PURE__*/jsxRuntime.jsx("div", {
      ...rest,
      className: Blankslate_module.Container,
      children: /*#__PURE__*/jsxRuntime.jsx("div", {
        className: clsx.clsx(Blankslate_module.Blankslate, className),
        "data-border": border ? '' : undefined,
        "data-narrow": narrow ? '' : undefined,
        "data-spacious": spacious ? '' : undefined,
        "data-size": size,
        children: children
      })
    })
  });
}
Blankslate.displayName = "Blankslate";
function Visual({
  children,
  className,
  ...rest
}) {
  return /*#__PURE__*/jsxRuntime.jsx("span", {
    ...rest,
    className: clsx.clsx('Blankslate-Visual', Blankslate_module.Visual, className),
    children: children
  });
}
Visual.displayName = "Visual";
function Heading({
  as: Component = 'h2',
  children,
  className,
  ...rest
}) {
  return /*#__PURE__*/jsxRuntime.jsx(Component, {
    ...rest,
    className: clsx.clsx('Blankslate-Heading', Blankslate_module.Heading, className),
    children: children
  });
}
Heading.displayName = "Heading";
function Description({
  children,
  className,
  ...rest
}) {
  return /*#__PURE__*/jsxRuntime.jsx("p", {
    ...rest,
    className: clsx.clsx('Blankslate-Description', Blankslate_module.Description, className),
    children: children
  });
}
Description.displayName = "Description";
function PrimaryAction({
  children,
  href,
  ...props
}) {
  const {
    size
  } = BlankslateContext.useBlankslate();
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    className: clsx.clsx('Blankslate-Action', Blankslate_module.Action),
    children: /*#__PURE__*/jsxRuntime.jsx(Button.ButtonComponent, {
      ...props,
      as: href ? 'a' : 'button',
      href: href,
      variant: "primary",
      size: size === 'small' ? 'small' : undefined,
      children: children
    })
  });
}
PrimaryAction.displayName = "PrimaryAction";
function SecondaryAction({
  children,
  href
}) {
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    className: clsx.clsx('Blankslate-Action', Blankslate_module.Action),
    children: /*#__PURE__*/jsxRuntime.jsx(Link, {
      href: href,
      children: children
    })
  });
}
SecondaryAction.displayName = "SecondaryAction";

exports.Blankslate = Blankslate;
exports.Description = Description;
exports.Heading = Heading;
exports.PrimaryAction = PrimaryAction;
exports.SecondaryAction = SecondaryAction;
exports.Visual = Visual;
