'use strict';

var octiconsReact = require('@primer/octicons-react');
var clsx = require('clsx');
var React = require('react');
var _VisuallyHidden = require('../_VisuallyHidden.js');
var sorting = require('./sorting.js');
var useTable = require('./useTable.js');
var SkeletonText = require('../experimental/Skeleton/SkeletonText.js');
var ButtonReset = require('../internal/components/ButtonReset.js');
var Table_module = require('./Table.module.css.js');
var defaultSxProp = require('../utils/defaultSxProp.js');
var BoxWithFallback = require('../internal/components/BoxWithFallback.js');
var jsxRuntime = require('react/jsx-runtime');
var ScrollableRegion = require('../ScrollableRegion/ScrollableRegion.js');
var Text = require('../Text/Text.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

const Table = /*#__PURE__*/React__default.default.forwardRef(function Table({
  'aria-labelledby': labelledby,
  cellPadding = 'normal',
  className,
  gridTemplateColumns,
  ...rest
}, ref) {
  return (
    /*#__PURE__*/
    // TODO update type to be non-optional in next major release
    // @ts-expect-error this type should be required in the next major version
    jsxRuntime.jsx(ScrollableRegion.ScrollableRegion, {
      "aria-labelledby": labelledby,
      className: clsx.clsx('TableOverflowWrapper', Table_module.TableOverflowWrapper),
      children: /*#__PURE__*/jsxRuntime.jsx("table", {
        ...rest,
        "aria-labelledby": labelledby,
        "data-cell-padding": cellPadding,
        className: clsx.clsx(className, 'Table', Table_module.Table),
        role: "table",
        ref: ref,
        style: {
          '--grid-template-columns': gridTemplateColumns
        }
      })
    })
  );
});

// ----------------------------------------------------------------------------
// TableHead
// ----------------------------------------------------------------------------

function TableHead({
  children
}) {
  return (
    /*#__PURE__*/
    // We need to explicitly pass this role because some ATs and browsers drop table semantics
    // when we use `display: contents` or `display: grid` in the table
    jsxRuntime.jsx("thead", {
      className: clsx.clsx('TableHead', Table_module.TableHead),
      role: "rowgroup",
      children: children
    })
  );
}
TableHead.displayName = "TableHead"; // ----------------------------------------------------------------------------
// TableBody
// ----------------------------------------------------------------------------
function TableBody({
  children
}) {
  return (
    /*#__PURE__*/
    // We need to explicitly pass this role because some ATs and browsers drop table semantics
    // when we use `display: contents` or `display: grid` in the table
    jsxRuntime.jsx("tbody", {
      className: clsx.clsx('TableBody', Table_module.TableBody),
      role: "rowgroup",
      children: children
    })
  );
}
TableBody.displayName = "TableBody"; // ----------------------------------------------------------------------------
// TableHeader
// ----------------------------------------------------------------------------
function TableHeader({
  align,
  children,
  ...rest
}) {
  return /*#__PURE__*/jsxRuntime.jsx("th", {
    ...rest,
    className: clsx.clsx('TableHeader', Table_module.TableHeader),
    role: "columnheader",
    scope: "col",
    "data-cell-align": align,
    children: children
  });
}
TableHeader.displayName = "TableHeader";
function TableSortHeader({
  align,
  children,
  direction,
  onToggleSort,
  ...rest
}) {
  const ariaSort = direction === 'DESC' ? 'descending' : direction === 'ASC' ? 'ascending' : undefined;
  return /*#__PURE__*/jsxRuntime.jsx(TableHeader, {
    ...rest,
    "aria-sort": ariaSort,
    align: align,
    children: /*#__PURE__*/jsxRuntime.jsxs(ButtonReset.Button, {
      type: "button",
      className: clsx.clsx('TableSortButton', Table_module.TableSortButton),
      onClick: () => {
        onToggleSort();
      },
      children: [children, direction === sorting.SortDirection.NONE || direction === sorting.SortDirection.ASC ? /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
        children: [/*#__PURE__*/jsxRuntime.jsx(octiconsReact.SortAscIcon, {
          className: clsx.clsx('TableSortIcon', 'TableSortIcon--ascending', Table_module.TableSortIcon, Table_module['TableSortIcon--ascending'])
        }), direction === sorting.SortDirection.NONE ? /*#__PURE__*/jsxRuntime.jsx(_VisuallyHidden, {
          children: "sort ascending"
        }) : null]
      }) : null, direction === sorting.SortDirection.DESC ? /*#__PURE__*/jsxRuntime.jsx(octiconsReact.SortDescIcon, {
        className: clsx.clsx('TableSortIcon', 'TableSortIcon--descending', Table_module.TableSortIcon, Table_module['TableSortIcon--descending'])
      }) : null]
    })
  });
}
TableSortHeader.displayName = "TableSortHeader"; // ----------------------------------------------------------------------------
// TableRow
// ----------------------------------------------------------------------------
function TableRow({
  children,
  ...rest
}) {
  return /*#__PURE__*/jsxRuntime.jsx("tr", {
    ...rest,
    className: clsx.clsx('TableRow', Table_module.TableRow),
    role: "row",
    children: children
  });
}
TableRow.displayName = "TableRow"; // ----------------------------------------------------------------------------
// TableCell
// ----------------------------------------------------------------------------
function TableCell({
  align,
  className,
  children,
  scope,
  ...rest
}) {
  const BaseComponent = scope ? 'th' : 'td';
  const role = scope ? 'rowheader' : 'cell';
  return /*#__PURE__*/jsxRuntime.jsx(BaseComponent, {
    ...rest,
    className: clsx.clsx('TableCell', className, Table_module.TableCell),
    scope: scope,
    role: role,
    "data-cell-align": align,
    children: children
  });
}
TableCell.displayName = "TableCell";
function TableCellPlaceholder({
  children
}) {
  return /*#__PURE__*/jsxRuntime.jsx(Text, {
    color: "fg.subtle",
    children: children
  });
}
TableCellPlaceholder.displayName = "TableCellPlaceholder"; // ----------------------------------------------------------------------------
// TableContainer
// ----------------------------------------------------------------------------
function TableContainer({
  children,
  className,
  sx: sxProp = defaultSxProp.defaultSxProp,
  ...rest
}) {
  return /*#__PURE__*/jsxRuntime.jsx(BoxWithFallback.BoxWithFallback, {
    ...rest,
    className: clsx.clsx(className, Table_module.TableContainer),
    sx: sxProp,
    children: children
  });
}
TableContainer.displayName = "TableContainer";
const TableTitle = /*#__PURE__*/React__default.default.forwardRef(function TableTitle({
  as: Component = 'h2',
  children,
  id
}, ref) {
  const BaseComponent = Component;
  return /*#__PURE__*/jsxRuntime.jsx(BaseComponent, {
    className: clsx.clsx('TableTitle', Table_module.TableTitle),
    id: id,
    ref: ref,
    children: children
  });
});
function TableSubtitle({
  as: BaseComponent = 'div',
  children,
  id
}) {
  return /*#__PURE__*/jsxRuntime.jsx(BaseComponent, {
    className: clsx.clsx('TableSubtitle', Table_module.TableSubtitle),
    id: id,
    children: children
  });
}
TableSubtitle.displayName = "TableSubtitle";
function TableDivider() {
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    className: clsx.clsx('TableDivider', Table_module.TableDivider),
    role: "presentation"
  });
}
TableDivider.displayName = "TableDivider";
function TableActions({
  children
}) {
  return /*#__PURE__*/jsxRuntime.jsx("div", {
    className: clsx.clsx('TableActions', Table_module.TableActions),
    children: children
  });
}
TableActions.displayName = "TableActions"; // ----------------------------------------------------------------------------
// TableSkeleton
// ----------------------------------------------------------------------------
function TableSkeleton({
  cellPadding,
  columns,
  rows = 10,
  ...rest
}) {
  const {
    gridTemplateColumns
  } = useTable.useTableLayout(columns);
  return /*#__PURE__*/jsxRuntime.jsxs(Table, {
    ...rest,
    cellPadding: cellPadding,
    gridTemplateColumns: gridTemplateColumns,
    children: [/*#__PURE__*/jsxRuntime.jsx(TableHead, {
      children: /*#__PURE__*/jsxRuntime.jsx(TableRow, {
        children: Array.isArray(columns) ? columns.map((column, i) => {
          return /*#__PURE__*/jsxRuntime.jsx(TableHeader, {
            children: typeof column.header === 'string' ? column.header : column.header()
          }, i);
        }) : null
      })
    }), /*#__PURE__*/jsxRuntime.jsx(TableBody, {
      children: /*#__PURE__*/jsxRuntime.jsx(TableRow, {
        children: Array.from({
          length: columns.length
        }).map((_, i) => {
          return /*#__PURE__*/jsxRuntime.jsxs(TableCell, {
            className: clsx.clsx('TableCellSkeleton', Table_module.TableCellSkeleton),
            children: [/*#__PURE__*/jsxRuntime.jsx(_VisuallyHidden, {
              children: "Loading"
            }), /*#__PURE__*/jsxRuntime.jsx("div", {
              className: clsx.clsx('TableCellSkeletonItems', Table_module.TableCellSkeletonItems),
              children: Array.from({
                length: rows
              }).map((_, i) => {
                return /*#__PURE__*/jsxRuntime.jsx("div", {
                  className: clsx.clsx('TableCellSkeletonItem', Table_module.TableCellSkeletonItem),
                  children: /*#__PURE__*/jsxRuntime.jsx(SkeletonText.SkeletonText, {})
                }, i);
              })
            })]
          }, i);
        })
      })
    })]
  });
}
TableSkeleton.displayName = "TableSkeleton";

exports.Table = Table;
exports.TableActions = TableActions;
exports.TableBody = TableBody;
exports.TableCell = TableCell;
exports.TableCellPlaceholder = TableCellPlaceholder;
exports.TableContainer = TableContainer;
exports.TableDivider = TableDivider;
exports.TableHead = TableHead;
exports.TableHeader = TableHeader;
exports.TableRow = TableRow;
exports.TableSkeleton = TableSkeleton;
exports.TableSortHeader = TableSortHeader;
exports.TableSubtitle = TableSubtitle;
exports.TableTitle = TableTitle;
