'use strict';

var octiconsReact = require('@primer/octicons-react');
var React = require('react');
var index = require('../ActionList/index.js');
var Item$1 = require('../ActionList/Item.js');
var ActionListContainerContext = require('../ActionList/ActionListContainerContext.js');
require('@styled-system/css');
var merge = require('deepmerge');
var defaultSxProp = require('../utils/defaultSxProp.js');
var useId = require('../hooks/useId.js');
var useIsomorphicLayoutEffect = require('../utils/useIsomorphicLayoutEffect.js');
var ActionList_module = require('../ActionList/ActionList.module.css.js');
var ReactDOM = require('react-dom');
var BoxWithFallback = require('../internal/components/BoxWithFallback.js');
var jsxRuntime = require('react/jsx-runtime');
var Box = require('../Box/Box.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);
var merge__default = /*#__PURE__*/_interopDefault(merge);

const Root = /*#__PURE__*/React__default.default.forwardRef(({
  children,
  ...props
}, ref) => {
  return /*#__PURE__*/jsxRuntime.jsx(BoxWithFallback.BoxWithFallback, {
    as: "nav",
    ...props,
    ref: ref,
    children: /*#__PURE__*/jsxRuntime.jsx(ActionListContainerContext.ActionListContainerContext.Provider, {
      value: {
        container: 'NavList'
      },
      children: /*#__PURE__*/jsxRuntime.jsx(index.ActionList, {
        children: children
      })
    })
  });
});
Root.displayName = 'NavList';

// ----------------------------------------------------------------------------
// NavList.Item

const Item = /*#__PURE__*/React__default.default.forwardRef(({
  'aria-current': ariaCurrent,
  children,
  defaultOpen,
  sx: sxProp = defaultSxProp.defaultSxProp,
  ...props
}, ref) => {
  const {
    depth
  } = React__default.default.useContext(SubNavContext);

  // Get SubNav from children
  const subNav = React__default.default.Children.toArray(children).find(child => /*#__PURE__*/React.isValidElement(child) && child.type === SubNav);

  // Get children without SubNav or TrailingAction
  const childrenWithoutSubNavOrTrailingAction = React__default.default.Children.toArray(children).filter(child => /*#__PURE__*/React.isValidElement(child) ? child.type !== SubNav && child.type !== TrailingAction : true);
  if (! /*#__PURE__*/React.isValidElement(subNav) && defaultOpen)
    // eslint-disable-next-line no-console
    console.error('NavList.Item must have a NavList.SubNav to use defaultOpen.');

  // Render ItemWithSubNav if SubNav is present
  if (subNav && /*#__PURE__*/React.isValidElement(subNav)) {
    return /*#__PURE__*/jsxRuntime.jsx(ItemWithSubNav, {
      subNav: subNav,
      depth: depth,
      defaultOpen: defaultOpen,
      sx: sxProp,
      style: {
        '--subitem-depth': depth
      },
      children: childrenWithoutSubNavOrTrailingAction
    });
  }
  return /*#__PURE__*/jsxRuntime.jsx(index.ActionList.LinkItem, {
    ref: ref,
    "aria-current": ariaCurrent,
    active: Boolean(ariaCurrent) && ariaCurrent !== 'false',
    style: {
      '--subitem-depth': depth
    },
    ...props,
    children: children
  });
});
Item.displayName = 'NavList.Item';

// ----------------------------------------------------------------------------
// ItemWithSubNav (internal)

const ItemWithSubNavContext = /*#__PURE__*/React__default.default.createContext({
  buttonId: '',
  subNavId: '',
  isOpen: false
});
function ItemWithSubNav({
  children,
  subNav,
  depth: _depth,
  defaultOpen,
  style,
  sx: sxProp = defaultSxProp.defaultSxProp
}) {
  var _ref;
  const buttonId = useId.useId();
  const subNavId = useId.useId();
  const [isOpen, setIsOpen] = React__default.default.useState((_ref = defaultOpen || null) !== null && _ref !== void 0 ? _ref : false);
  const subNavRef = React__default.default.useRef(null);
  const [containsCurrentItem, setContainsCurrentItem] = React__default.default.useState(false);
  useIsomorphicLayoutEffect(() => {
    if (subNavRef.current) {
      // Check if SubNav contains current item
      // valid values: page, step, location, date, time, true and false
      const currentItem = subNavRef.current.querySelector('[aria-current]:not([aria-current=false])');
      if (currentItem) {
        setContainsCurrentItem(true);
        setIsOpen(true);
      }
    }
  }, [subNav, buttonId]);
  if (sxProp !== defaultSxProp.defaultSxProp) {
    return /*#__PURE__*/jsxRuntime.jsx(ItemWithSubNavContext.Provider, {
      value: {
        buttonId,
        subNavId,
        isOpen
      },
      children: /*#__PURE__*/jsxRuntime.jsxs(index.ActionList.Item, {
        id: buttonId,
        "aria-expanded": isOpen,
        "aria-controls": subNavId,
        active: !isOpen && containsCurrentItem,
        onSelect: () => setIsOpen(open => !open),
        style: style,
        sx: sxProp,
        children: [children, /*#__PURE__*/jsxRuntime.jsx(index.ActionList.TrailingVisual, {
          children: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.ChevronDownIcon, {
            className: ActionList_module.ExpandIcon
          })
        }), /*#__PURE__*/jsxRuntime.jsx(Item$1.SubItem, {
          children: /*#__PURE__*/React__default.default.cloneElement(subNav, {
            ref: subNavRef
          })
        })]
      })
    });
  }
  return /*#__PURE__*/jsxRuntime.jsx(ItemWithSubNavContext.Provider, {
    value: {
      buttonId,
      subNavId,
      isOpen
    },
    children: /*#__PURE__*/jsxRuntime.jsxs(index.ActionList.Item, {
      id: buttonId,
      "aria-expanded": isOpen,
      "aria-controls": subNavId,
      active: !isOpen && containsCurrentItem,
      onSelect: () => setIsOpen(open => !open),
      style: style,
      children: [children, /*#__PURE__*/jsxRuntime.jsx(index.ActionList.TrailingVisual, {
        children: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.ChevronDownIcon, {
          className: ActionList_module.ExpandIcon
        })
      }), /*#__PURE__*/jsxRuntime.jsx(Item$1.SubItem, {
        children: /*#__PURE__*/React__default.default.cloneElement(subNav, {
          ref: subNavRef
        })
      })]
    })
  });
}
ItemWithSubNav.displayName = "ItemWithSubNav"; // ----------------------------------------------------------------------------
// NavList.SubNav
const SubNavContext = /*#__PURE__*/React__default.default.createContext({
  depth: 0
});

// NOTE: SubNav must be a direct child of an Item
const SubNav = /*#__PURE__*/React__default.default.forwardRef(({
  children,
  sx: sxProp = defaultSxProp.defaultSxProp
}, forwardedRef) => {
  const {
    buttonId,
    subNavId
  } = React__default.default.useContext(ItemWithSubNavContext);
  const {
    depth
  } = React__default.default.useContext(SubNavContext);
  if (!buttonId || !subNavId) {
    // eslint-disable-next-line no-console
    console.error('NavList.SubNav must be a child of a NavList.Item');
  }
  if (depth > 3) {
    // TODO: write a more informative error message that directs people to rethink their IA
    // eslint-disable-next-line no-console
    console.error('NavList.SubNav only supports four levels of nesting');
    return null;
  }
  if (sxProp !== defaultSxProp.defaultSxProp) {
    return /*#__PURE__*/jsxRuntime.jsx(SubNavContext.Provider, {
      value: {
        depth: depth + 1
      },
      children: /*#__PURE__*/jsxRuntime.jsx(Box, {
        as: "ul",
        id: subNavId,
        "aria-labelledby": buttonId,
        className: ActionList_module.SubGroup,
        ref: forwardedRef,
        sx: sxProp,
        children: children
      })
    });
  }
  return /*#__PURE__*/jsxRuntime.jsx(SubNavContext.Provider, {
    value: {
      depth: depth + 1
    },
    children: /*#__PURE__*/jsxRuntime.jsx("ul", {
      className: ActionList_module.SubGroup,
      id: subNavId,
      "aria-labelledby": buttonId,
      ref: forwardedRef,
      children: children
    })
  });
});
SubNav.displayName = 'NavList.SubNav';

// ----------------------------------------------------------------------------
// NavList.LeadingVisual

const LeadingVisual = index.ActionList.LeadingVisual;
LeadingVisual.displayName = 'NavList.LeadingVisual';

// ----------------------------------------------------------------------------
// NavList.TrailingVisual

const TrailingVisual = index.ActionList.TrailingVisual;
TrailingVisual.displayName = 'NavList.TrailingVisual';

// ----------------------------------------------------------------------------
// NavList.Divider

const Divider = index.ActionList.Divider;
Divider.displayName = 'NavList.Divider';

// NavList.TrailingAction

const TrailingAction = index.ActionList.TrailingAction;
TrailingAction.displayName = 'NavList.TrailingAction';

// ----------------------------------------------------------------------------
// NavList.Group

const defaultSx = {};
const Group = ({
  title,
  children,
  sx: sxProp = defaultSx,
  ...props
}) => {
  if (sxProp !== defaultSx) {
    return /*#__PURE__*/jsxRuntime.jsxs(Box, {
      sx: sxProp,
      as: "li",
      "data-component": "ActionList.Group",
      children: [title ? /*#__PURE__*/jsxRuntime.jsx(index.ActionList.GroupHeading, {
        children: title
      }) : null, children]
    });
  }
  return /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
    children: [/*#__PURE__*/jsxRuntime.jsx(index.ActionList.Divider, {}), /*#__PURE__*/jsxRuntime.jsxs(index.ActionList.Group, {
      ...props,
      children: [title ? /*#__PURE__*/jsxRuntime.jsx(index.ActionList.GroupHeading, {
        as: "h3",
        "data-component": "ActionList.GroupHeading",
        children: title
      }) : null, children]
    })]
  });
};
// ----------------------------------------------------------------------------
// NavList.GroupExpand

const GroupExpand = /*#__PURE__*/React__default.default.forwardRef(({
  label = 'Show more',
  pages = 0,
  items,
  renderItem,
  ...props
}, forwardedRef) => {
  const [currentPage, setCurrentPage] = React__default.default.useState(0);
  const groupId = useId.useId();
  const itemsPerPage = items.length / pages;
  const amountToShow = pages === 0 ? items.length : Math.ceil(itemsPerPage * currentPage);
  const focusTargetIndex = currentPage === 1 ? 0 : amountToShow - Math.floor(itemsPerPage);
  return /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
    children: [currentPage > 0 ? /*#__PURE__*/jsxRuntime.jsx(jsxRuntime.Fragment, {
      children: items.map((itemArr, index) => {
        const {
          text,
          trailingVisual: TrailingVisualIcon,
          leadingVisual: LeadingVisualIcon,
          trailingAction,
          ...rest
        } = itemArr;
        const {
          icon,
          label: actionLabel,
          ...actionProps
        } = trailingAction || {};
        const focusTarget = index === focusTargetIndex ? groupId : undefined;
        if (index < amountToShow) {
          if (renderItem) {
            return renderItem({
              ...itemArr,
              ['data-expand-focus-target']: focusTarget
            });
          }
          return /*#__PURE__*/React.createElement(Item, {
            ...rest,
            key: index,
            "data-expand-focus-target": focusTarget
          }, LeadingVisualIcon ? /*#__PURE__*/jsxRuntime.jsx(LeadingVisual, {
            children: /*#__PURE__*/jsxRuntime.jsx(LeadingVisualIcon, {})
          }) : null, text, TrailingVisualIcon ? /*#__PURE__*/jsxRuntime.jsx(TrailingVisual, {
            children: /*#__PURE__*/jsxRuntime.jsx(TrailingVisualIcon, {})
          }) : null, trailingAction ? /*#__PURE__*/jsxRuntime.jsx(TrailingAction, {
            ...actionProps,
            icon: icon,
            label: actionLabel || ''
          }) : null);
        }
      })
    }) : null, currentPage < pages || currentPage === 0 ? /*#__PURE__*/jsxRuntime.jsxs(index.ActionList.Item, {
      as: "button",
      "aria-expanded": "false",
      ref: forwardedRef,
      onSelect: () => {
        ReactDOM.flushSync(() => {
          setCurrentPage(currentPage + 1);
        });
        const focusTarget = Array.from(document.querySelectorAll(`[data-expand-focus-target="${groupId}"]`));
        if (focusTarget.length > 0) {
          focusTarget[focusTarget.length - 1].focus();
        }
      },
      ...props,
      children: [label, /*#__PURE__*/jsxRuntime.jsx(TrailingVisual, {
        children: /*#__PURE__*/jsxRuntime.jsx(octiconsReact.PlusIcon, {})
      })]
    }) : null]
  });
});

// ----------------------------------------------------------------------------
// NavList.GroupHeading

/**
 * This is an alternative to the `title` prop on `NavList.Group`.
 * It was primarily added to allow links in group headings.
 */
const GroupHeading = ({
  as = 'h3',
  sx: sxProp = defaultSxProp.defaultSxProp,
  ...rest
}) => {
  return /*#__PURE__*/jsxRuntime.jsx(index.ActionList.GroupHeading, {
    as: as,
    sx: merge__default.default({
      '> a {': {
        color: 'var(--fgColor-default)',
        textDecoration: 'inherit',
        ':hover': {
          textDecoration: 'underline'
        }
      }
    }, sxProp),
    "data-component": "NavList.GroupHeading",
    headingWrapElement: "li",
    ...rest
  });
};
GroupHeading.displayName = "GroupHeading";
// ----------------------------------------------------------------------------
// Export

const NavList = Object.assign(Root, {
  Item,
  SubNav,
  LeadingVisual,
  TrailingVisual,
  TrailingAction,
  Divider,
  Group,
  GroupExpand,
  GroupHeading
});

exports.GroupExpand = GroupExpand;
exports.NavList = NavList;
