'use strict';

var styled = require('styled-components');
var sx = require('../sx.js');
var Spinner_module = require('./Spinner.module.css.js');
var clsx = require('clsx');
var jsxRuntime = require('react/jsx-runtime');
var useId = require('../hooks/useId.js');
var VisuallyHidden = require('../VisuallyHidden/VisuallyHidden.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var styled__default = /*#__PURE__*/_interopDefault(styled);

const sizeMap = {
  small: '16px',
  medium: '32px',
  large: '64px'
};
function Spinner({
  size: sizeKey = 'medium',
  srText = 'Loading',
  'aria-label': ariaLabel,
  className,
  style,
  ...props
}) {
  const size = sizeMap[sizeKey];
  const hasHiddenLabel = srText !== null && ariaLabel === undefined;
  const labelId = useId.useId();
  return /*#__PURE__*/ /* inline-flex removes the extra line height */jsxRuntime.jsxs("span", {
    className: Spinner_module.Box,
    children: [/*#__PURE__*/jsxRuntime.jsxs("svg", {
      height: size,
      width: size,
      viewBox: "0 0 16 16",
      fill: "none",
      "aria-hidden": true,
      "aria-label": ariaLabel !== null && ariaLabel !== void 0 ? ariaLabel : undefined,
      "aria-labelledby": hasHiddenLabel ? labelId : undefined,
      className: className,
      style: style,
      ...props,
      children: [/*#__PURE__*/jsxRuntime.jsx("circle", {
        cx: "8",
        cy: "8",
        r: "7",
        stroke: "currentColor",
        strokeOpacity: "0.25",
        strokeWidth: "2",
        vectorEffect: "non-scaling-stroke"
      }), /*#__PURE__*/jsxRuntime.jsx("path", {
        d: "M15 8a7.002 7.002 0 00-7-7",
        stroke: "currentColor",
        strokeWidth: "2",
        strokeLinecap: "round",
        vectorEffect: "non-scaling-stroke"
      })]
    }), hasHiddenLabel ? /*#__PURE__*/jsxRuntime.jsx(VisuallyHidden.VisuallyHidden, {
      id: labelId,
      children: srText
    }) : null]
  });
}
Spinner.displayName = "Spinner";
const StyledBaseSpinner = styled__default.default.div.withConfig({
  displayName: "Spinner__StyledBaseSpinner",
  componentId: "sc-1knt686-0"
})(["", ""], sx.default);
function StyledSpinner({
  sx,
  className,
  ...props
}) {
  if (sx) {
    return /*#__PURE__*/jsxRuntime.jsx(StyledBaseSpinner, {
      sx: sx,
      as: Spinner,
      className: clsx.clsx(className, Spinner_module.SpinnerAnimation),
      ...props
    });
  }
  return /*#__PURE__*/jsxRuntime.jsx(Spinner, {
    className: clsx.clsx(className, Spinner_module.SpinnerAnimation),
    ...props
  });
}
StyledSpinner.displayName = "StyledSpinner";
StyledSpinner.displayName = 'Spinner';

module.exports = StyledSpinner;
