'use strict';

var React = require('react');
var defaultSxProp = require('../utils/defaultSxProp.js');
var TokenBase = require('./TokenBase.js');
var _RemoveTokenButton = require('./_RemoveTokenButton.js');
var _TokenTextContainer = require('./_TokenTextContainer.js');
var _VisuallyHidden = require('../_VisuallyHidden.js');
var Token_module = require('./Token.module.css.js');
var clsx = require('clsx');
var jsxRuntime = require('react/jsx-runtime');

const tokenBorderWidthPx = 1;
const LeadingVisualContainer = ({
  children,
  size
}) => /*#__PURE__*/jsxRuntime.jsx("div", {
  className: clsx.clsx(Token_module.LeadingVisualContainer, {
    [Token_module.LargeLeadingVisual]: size && ['large', 'xlarge'].includes(size)
  }),
  children: children
});
LeadingVisualContainer.displayName = "LeadingVisualContainer";
const Token = /*#__PURE__*/React.forwardRef((props, forwardedRef) => {
  const {
    as,
    onRemove,
    id,
    leadingVisual: LeadingVisual,
    text,
    size = TokenBase.defaultTokenSize,
    hideRemoveButton,
    href,
    onClick,
    sx: sxProp = defaultSxProp.defaultSxProp,
    className,
    style,
    ...rest
  } = props;
  const hasMultipleActionTargets = TokenBase.isTokenInteractive(props) && Boolean(onRemove) && !hideRemoveButton;
  const onRemoveClick = e => {
    e.stopPropagation();
    onRemove && onRemove();
  };
  const interactiveTokenProps = {
    as,
    href,
    onClick
  };
  return /*#__PURE__*/jsxRuntime.jsxs(TokenBase.default, {
    onRemove: onRemove,
    id: id === null || id === void 0 ? void 0 : id.toString(),
    className: clsx.clsx(className, Token_module.Token),
    text: text,
    size: size,
    sx: sxProp,
    "data-is-selected": props.isSelected,
    "data-is-remove-btn": !(hideRemoveButton || !onRemove),
    ...(!hasMultipleActionTargets ? interactiveTokenProps : {}),
    ...rest,
    ref: forwardedRef,
    style: {
      borderWidth: `${tokenBorderWidthPx}px`,
      ...style
    },
    children: [LeadingVisual ? /*#__PURE__*/jsxRuntime.jsx(LeadingVisualContainer, {
      size: size,
      children: /*#__PURE__*/jsxRuntime.jsx(LeadingVisual, {})
    }) : null, /*#__PURE__*/jsxRuntime.jsxs(_TokenTextContainer, {
      ...(hasMultipleActionTargets ? interactiveTokenProps : {}),
      children: [text, onRemove && /*#__PURE__*/jsxRuntime.jsx(_VisuallyHidden, {
        children: " (press backspace or delete to remove)"
      })]
    }), !hideRemoveButton && onRemove ? /*#__PURE__*/jsxRuntime.jsx(_RemoveTokenButton, {
      borderOffset: tokenBorderWidthPx,
      onClick: onRemoveClick,
      size: size,
      isParentInteractive: TokenBase.isTokenInteractive(props),
      "aria-hidden": hasMultipleActionTargets ? 'true' : 'false'
    }) : null]
  });
});
Token.displayName = 'Token';

module.exports = Token;
