import type { SxProp } from '../sx';
import type React from 'react';
import { type HTMLAttributes } from 'react';
/**
 * Provides a component that implements the "visually hidden" technique. This is
 * analagous to the common `sr-only` class. Children that are rendered inside
 * this component will not be visible but will be available to screen readers.
 *
 * Note: if this component, or a descendant, has focus then this component will
 * no longer be visually hidden.
 *
 * @see https://www.scottohara.me/blog/2023/03/21/visually-hidden-hack.html
 */
export declare const VisuallyHidden: ({ className, children, sx: sxProp, ...rest }: VisuallyHiddenProps) => React.JSX.Element;
export type VisuallyHiddenProps = React.PropsWithChildren<HTMLAttributes<HTMLSpanElement> & {
    className?: string;
} & SxProp>;
//# sourceMappingURL=VisuallyHidden.d.ts.map