'use strict';

var List = require('./ActionList/List.js');
var Item = require('./ActionList/Item.js');
var Divider = require('./ActionList/Divider.js');
var React = require('react');
var useProvidedStateOrCreate = require('../hooks/useProvidedStateOrCreate.js');
var jsxRuntime = require('react/jsx-runtime');
var useProvidedRefOrCreate = require('../hooks/useProvidedRefOrCreate.js');
var AnchoredOverlay = require('../AnchoredOverlay/AnchoredOverlay.js');
var Button = require('../Button/Button.js');

const ActionMenuItem = props => /*#__PURE__*/jsxRuntime.jsx(Item.Item, {
  role: "menuitem",
  ...props
});
ActionMenuItem.displayName = "ActionMenuItem";
ActionMenuItem.displayName = 'ActionMenu.Item';
const defaultRenderAnchor = props => /*#__PURE__*/jsxRuntime.jsx(Button.ButtonComponent, {
  ...props
});
defaultRenderAnchor.displayName = "defaultRenderAnchor";
const ActionMenuBase = ({
  anchorContent,
  renderAnchor = defaultRenderAnchor,
  anchorRef: externalAnchorRef,
  onAction,
  open,
  setOpen,
  overlayProps,
  items,
  ...listProps
}) => {
  const [combinedOpenState, setCombinedOpenState] = useProvidedStateOrCreate.useProvidedStateOrCreate(open, setOpen, false);
  const anchorRef = useProvidedRefOrCreate.useProvidedRefOrCreate(externalAnchorRef);
  const onOpen = React.useCallback(() => setCombinedOpenState(true), [setCombinedOpenState]);
  const onClose = React.useCallback(() => setCombinedOpenState(false), [setCombinedOpenState]);
  const renderMenuAnchor = React.useMemo(() => {
    if (renderAnchor === null) {
      return null;
    }
    return props => {
      return renderAnchor({
        'aria-label': 'menu',
        children: anchorContent,
        ...props
      });
    };
  }, [anchorContent, renderAnchor]);
  const itemsToRender = React.useMemo(() => {
    return items.map(item => {
      return {
        ...item,
        role: 'menuitem',
        onAction: (props, event) => {
          var _item$onAction;
          const actionCallback = (_item$onAction = item.onAction) !== null && _item$onAction !== void 0 ? _item$onAction : onAction;
          actionCallback === null || actionCallback === void 0 ? void 0 : actionCallback(props, event);
          if (!event.defaultPrevented) {
            onClose();
          }
        }
      };
    });
  }, [items, onAction, onClose]);
  return /*#__PURE__*/jsxRuntime.jsx(AnchoredOverlay.AnchoredOverlay, {
    renderAnchor: renderMenuAnchor,
    anchorRef: anchorRef,
    open: combinedOpenState,
    onOpen: onOpen,
    onClose: onClose,
    overlayProps: overlayProps,
    children: /*#__PURE__*/jsxRuntime.jsx(List.List, {
      ...listProps,
      role: "menu",
      items: itemsToRender
    })
  });
};
ActionMenuBase.displayName = "ActionMenuBase";
ActionMenuBase.displayName = 'ActionMenu';

/**
 * @deprecated Use ActionMenu with composable API instead. See https://primer.style/react/ActionMenu for more details.
 */
const ActionMenu = Object.assign(ActionMenuBase, {
  Divider: Divider.Divider,
  Item: ActionMenuItem
});

exports.ActionMenu = ActionMenu;
