'use strict';

var getColorFromHex = require('./getColorFromHex.js');
var ThemeProvider = require('../../ThemeProvider.js');
var clsx = require('clsx');
var IssueLabel_module = require('./IssueLabel.module.css.js');
var jsxRuntime = require('react/jsx-runtime');

function IssueLabel({
  className,
  fillColor,
  variant = 'gray',
  href,
  onClick,
  onFocus,
  text,
  as,
  id,
  ...rest
}) {
  // Error handling: `href` and `onClick` should not be set simultaneously
  if (href && onClick) {
    throw new Error('`href` and `onClick` cannot both be set. Choose either a link (`<a>`) or a button (`<button>`).');
  }
  const {
    resolvedColorScheme
  } = ThemeProvider.useTheme();
  const mode = resolvedColorScheme !== null && resolvedColorScheme !== void 0 && resolvedColorScheme.startsWith('dark') ? 'dark' : 'light';
  // TODO: get the bgColor, getting it from theme.colorScheme seems a bit sketchy
  const bgColors = {
    light: '#ffffff',
    dark: '#0d1117'
  };

  // Determine the component type: Prioritize `as`, then fallback to `href` or `onClick` logic
  let Component = 'span'; // Default to <span>

  if (as) {
    Component = as; // use 'as' prop if provided
  } else if (href) {
    Component = 'a'; // render as <a> if `href` is provided
  } else if (onClick) {
    Component = 'button'; // render as <button> if `onClick` is provided
  }
  const anchorProps = href ? {
    href
  } : {};
  return /*#__PURE__*/jsxRuntime.jsx(Component, {
    ...rest,
    ...anchorProps,
    onClick: onClick,
    onFocus: onFocus,
    id: id === null || id === void 0 ? void 0 : id.toString(),
    className: clsx.clsx(IssueLabel_module.IssueLabel, className),
    "data-variant": fillColor ? undefined : variant,
    style: fillColor ? getColorFromHex.getColorsFromHex(fillColor, resolvedColorScheme, bgColors[mode]) : undefined,
    children: text
  });
}
IssueLabel.displayName = "IssueLabel";

exports.IssueLabel = IssueLabel;
