'use strict';

var React = require('react');
var defaultSxProp = require('../../utils/defaultSxProp.js');
var includeSystemProps = require('../../utils/includeSystemProps.js');
var jsxRuntime = require('react/jsx-runtime');
var Box = require('../../Box/Box.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

/**
 * Utility to toggle rendering a Box component that receives sx props
 * or a "plain" component based on the provided `as` prop. Other props will be passed through to an element or component created with the `as` prop.
 *
 * @param sx - the sx prop to check against the default sx prop
 * @param defaultAs - the default component to use when `as` is not provided
 */
function toggleSxComponent(
// eslint-disable-next-line @typescript-eslint/no-explicit-any
defaultAs) {
  const Wrapper = /*#__PURE__*/React__default.default.forwardRef(function Wrapper({
    as: BaseComponent = defaultAs,
    sx: sxProp = defaultSxProp.defaultSxProp,
    ...rest
  }, ref) {
    if (sxProp !== defaultSxProp.defaultSxProp || includeSystemProps.includesSystemProps(rest)) {
      return /*#__PURE__*/jsxRuntime.jsx(Box, {
        as: BaseComponent,
        ...rest,
        sx: sxProp,
        ref: ref
      });
    }
    return /*#__PURE__*/jsxRuntime.jsx(BaseComponent, {
      ...rest,
      ref: ref
    });
  });
  return Wrapper;
}

exports.toggleSxComponent = toggleSxComponent;
